<?php

declare(strict_types=1);

namespace FiloBlu\RuleDayFromBirthday\Block\Adminhtml\System\Config;

use Magento\Framework\Api\SearchCriteriaBuilder;
use Magento\Framework\Data\OptionSourceInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\SalesRule\Api\Data\RuleInterface;
use Magento\SalesRule\Model\RuleRepository;

/**
 * @class SalesRule
 * @package FiloBlu\BirthdayCoupon\Config
 */
class SalesRule implements OptionSourceInterface
{

    /**
     * @var RuleRepository
     */
    private $ruleRepository;

    /**
     * @var SearchCriteriaBuilder
     */
    private $searchCriteriaBuilder;

    /**
     * @param RuleRepository $ruleRepository
     * @param SearchCriteriaBuilder $searchCriteriaBuilder
     */
    public function __construct(
        RuleRepository        $ruleRepository,
        SearchCriteriaBuilder $searchCriteriaBuilder
    ) {
        $this->ruleRepository = $ruleRepository;
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
    }

    /**
     * {@inheritdoc}
     * @throws LocalizedException
     */
    public function toOptionArray(): array
    {
        $result = [];
        foreach ($this->getSalesRules() as $rule) {
            $result[] = [
                'label' => 'id: ' . $rule->getRuleId() . ' - ' . $rule->getName(),
                'value' => $rule->getRuleId(),
            ];
        }

        return $result;
    }

    /**
     * @return RuleInterface[]
     * @throws LocalizedException
     */
    public function getSalesRules(): array
    {
        $searchResults = $this->ruleRepository
            ->getList($this->searchCriteriaBuilder->create());

        return $searchResults->getItems();
    }
}
