<?php

declare(strict_types=1);

namespace FiloBlu\RuleDayFromBirthday\Model;

use FiloBlu\RuleDayFromBirthday\Api\Data\CustomCouponInterface;
use Magento\Framework\DataObject;

/**
 * @class CustomCoupon
 * @package FiloBlu\RuleDayFromBirthday\Model
 */
class CustomCoupon extends DataObject implements CustomCouponInterface
{

    /**
     * @param int $id
     * @return CustomCouponInterface
     */
    public function setEntityId(int $id): CustomCouponInterface
    {
        return $this->setData(self::ENTITY_ID, $id);
    }

    /**
     * @return int|null
     */
    public function getRuleId(): ?int
    {
        return (int)$this->getData(self::RULE_ID);
    }

    /**
     * @param int $ruleId
     * @return CustomCouponInterface
     */
    public function setRuleId(int $ruleId): CustomCouponInterface
    {
        return $this->setData(self::RULE_ID, $ruleId);
    }

    /**
     * @return int|null
     */
    public function getExpirationDays(): ?int
    {
        return (int)$this->getData(self::EXPIRATION_DAYS);
    }

    /**
     * @param int $expirationDays
     * @return CustomCouponInterface
     */
    public function setExpirationDays(int $expirationDays): CustomCouponInterface
    {
        return $this->setData(self::EXPIRATION_DAYS, $expirationDays);
    }

    /**
     * @return string|null
     */
    public function getType(): ?string
    {
        return $this->getData(self::TYPE);
    }

    /**
     * @param string $type
     * @return CustomCouponInterface
     */
    public function setType(string $type): CustomCouponInterface
    {
        return $this->setData(self::TYPE, $type);
    }

    /**
     * @return string|null
     */
    public function getPrefix(): ?string
    {
        return $this->getData(self::PREFIX);
    }

    /**
     * @param string $prefix
     * @return CustomCouponInterface
     */
    public function setPrefix(string $prefix): CustomCouponInterface
    {
        return $this->setData(self::PREFIX, $prefix);
    }

    /**
     * @return string|null
     */
    public function getSuffix(): ?string
    {
        return $this->getData(self::SUFFIX);
    }

    /**
     * @param string $suffix
     * @return CustomCouponInterface
     */
    public function setSuffix(string $suffix): CustomCouponInterface
    {
        return $this->setData(self::SUFFIX, $suffix);
    }

    /**
     * @return int|null
     */
    public function getLength(): ?int
    {
        return (int)$this->getData(self::LENGTH);
    }

    /**
     * @param int $length
     * @return CustomCouponInterface
     */
    public function setLength(int $length): CustomCouponInterface
    {
        return $this->setData(self::LENGTH, $length);
    }

    /**
     * @return string|null
     */
    public function getFormat(): ?string
    {
        return $this->getData(self::FORMAT);
    }

    /**
     * @param string $format
     * @return CustomCouponInterface
     */
    public function setFormat(string $format): CustomCouponInterface
    {
        return $this->setData(self::FORMAT, $format);
    }

    /**
     * @return int|null
     */
    public function getDash(): ?int
    {
        return (int) $this->getData(self::DASH);
    }

    /**
     * @param int $dash
     * @return CustomCouponInterface
     */
    public function setDash(int $dash): CustomCouponInterface
    {
        return $this->setData(self::DASH, $dash);
    }

    /**
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->getEntityId();
    }

    /**
     * @return int|null
     */
    public function getEntityId(): ?int
    {
        return (int)$this->getData(self::ENTITY_ID);
    }
}
