<?php

declare(strict_types=1);

namespace FiloBlu\RuleDayFromBirthday\Model\SalesRule;

use Exception;

use FiloBlu\ExtCartRule\Api\Data\SalesRuleInterface;
use FiloBlu\RuleDayFromBirthday\Api\CustomCouponRepositoryInterface;
use FiloBlu\RuleDayFromBirthday\Api\Data\{CustomCouponInterfaceFactory, CustomCouponInterface};
use Magento\Framework\EntityManager\MetadataPool;
use Magento\Framework\EntityManager\Operation\ExtensionInterface;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\SalesRule\Api\Data\RuleInterface;

/**
 * @class SaveHandler
 * @package FiloBlu\RuleDayFromBirthday\Model
 */
class SaveHandler implements ExtensionInterface
{

    /**
     * @var MetadataPool
     */
    private $metadataPool;
    /**
     * @var CustomCouponRepositoryInterface
     */
    private $customCouponRepository;
    /**
     * @var CustomCouponInterfaceFactory
     */
    private $customCouponFactory;

    /**
     * @param MetadataPool $metadataPool
     * @param CustomCouponRepositoryInterface $customCouponRepository
     * @param CustomCouponInterfaceFactory $customCouponFactory
     */
    public function __construct(
        MetadataPool $metadataPool,
        CustomCouponRepositoryInterface $customCouponRepository,
        CustomCouponInterfaceFactory $customCouponFactory
    ) {
        $this->metadataPool = $metadataPool;
        $this->customCouponRepository = $customCouponRepository;
        $this->customCouponFactory = $customCouponFactory;
    }

    /**
     * @param object $entity
     * @param array $arguments
     * @return object
     * @throws CouldNotSaveException
     * @throws Exception
     */
    public function execute($entity, $arguments = [])
    {
        $metadata = $this->metadataPool->getMetadata(RuleInterface::class);
        $ruleId = $entity->getData('rule_id');
        if ($ruleId === null || $ruleId === 0) {
            return $entity;
        }

        $rowId = $entity->getData($metadata->getLinkField());
        if ($rowId === null || $ruleId === 0) {
            $rowId = $ruleId;
        }

        $extensionAttributes = $entity->getExtensionAttributes();
        if (isset($extensionAttributes['filoblu_sales_rule_coupon'])) {
            try {
                /** @var SalesRuleInterface $salesRule */
                $customCoupon = $this->customCouponRepository->getById($rowId);
            } catch (NoSuchEntityException $exception) {
                /** @var SalesRuleInterface $salesRule */
                $customCoupon = $this->customCouponFactory->create();
                $customCoupon->setRuleId((int) $ruleId);
            }

            $expirationDays = (int) $entity->getData('filoblu_coupon_expire_date') ?? 0;
            $type = in_array($entity->getData('filoblu_birthday_coupon'), ["1", 'birthday_coupon']) ? CustomCouponInterface::BIRTHDAY_COUPON_TYPE : '';
            $prefix = $entity->getData('coupons_prefix') ?? "";
            $suffix = $entity->getData('coupons_suffix') ?? "";
            $length = $entity->getData('coupons_length') ?? 0;
            $format = $entity->getData('coupons_format') ?? "alphanum";
            $dash = $entity->getData('coupons_dash') ?? 0;

            $customCoupon
                ->setRuleId((int) $ruleId)
                ->setEntityId((int) $rowId)
                ->setExpirationDays($expirationDays)
                ->setType($type)
                ->setPrefix($prefix)
                ->setSuffix($suffix)
                ->setLength((int) $length)
                ->setFormat($format)
                ->setDash((int) $dash);

            $this->customCouponRepository->save($customCoupon);
        }

        return $entity;
    }
}
